@@ -3,17 +3,22 @@ CLI entry-point for salt-api
 '''
 # Import salt libs
 from salt.utils.parsers import (
-        ConfigDirMixIn,
-        LogLevelMixIn,
-        OptionParser,
-        OptionParserMeta)
+    ConfigDirMixIn,
+    DaemonMixIn,
+    LogLevelMixIn,
+    MergeConfigMixIn,
+    OptionParser,
+    OptionParserMeta,
+    PidfileMixin)
 
 # Import salt-api libs
 import saltapi.client
 import saltapi.config
 import saltapi.version
 
-class SaltAPI(OptionParser, ConfigDirMixIn, LogLevelMixIn):
+
+class SaltAPI(OptionParser, ConfigDirMixIn, LogLevelMixIn, PidfileMixin,
+              DaemonMixIn, MergeConfigMixIn):
     '''
     The cli parser object used to fire up the salt api system.
     '''
@@ -30,5 +35,7 @@ class SaltAPI(OptionParser, ConfigDirMixIn, LogLevelMixIn):
         '''
         self.parse_args()
         self.process_config_dir()
+        self.daemonize_if_required()
+        self.set_pidfile()
         client = saltapi.client.SaltAPIClient(self.config)
         client.run()
